1.3. Available cubes — CubicWeb 3.11.0

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Repository development »
- 1. Cubes »

# 1.3. Available cubes

An instance is made of several basic cubes. In the set of available basic cubes we can find for example:

## 1.3.1. Base entity types

- addressbook: PhoneNumber and PostalAddress
- card: Card, generic documenting card
- event: Event (define events, display them in calendars)
- file: File (to allow users to upload and store binary or text files)
- link: Link (to collect links to web resources)
- mailinglist: MailingList (to reference a mailing-list and the URLs for its archives and its admin interface)
- person: Person (easily mixed with addressbook)
- task: Task (something to be done between start and stop date)
- zone: Zone (to define places within larger places, for example a city in a state in a country)

## 1.3.2. Classification

- folder: Folder (to organize things by grouping them in folders)
- keyword: Keyword (to define classification schemes)
- tag: Tag (to tag anything)

## 1.3.3. Other features

- basket: Basket (like a shopping cart)
- blog: a blogging system using Blog and BlogEntry entity types
- comment: system to attach comment threads to entities)
- email: archiving management for emails (Email, Emailpart, Emailthread), trigger action in cubicweb through email

To declare the use of a cube, once installed, add the name of the cube and its dependency relation in the __depends_cubes__ dictionary defined in the file __pkginfo__.py of your own component.

Note

The listed cubes above are available as debian-packages on CubicWeb’s forge.

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Repository development »
- 1. Cubes »